@@ -199,7 +199,7 @@ class DirectChannel(RequestWrapper):
                          token=None, mesetoken=None, providerincasso=None, nometitolare=None, datarichiesta=None, dataprossimarichiesta=None,
                          codicefiscaletitolare=None, indirizzotitolare=None, localitatitolare=None, cartaprepagata=None,
                          provinciatitolare=None, annotoken=None, cap=None, codicedialogatoreinterno=None, codicedialogatoreesterno=None, nomedialogatoreesterno=None,
-                         flagallineamento=None, datapromessa=None, codiceagenzia=None):
+                         flagallineamento=None, datapromessa=None, codiceagenzia=None, flagoneoff=None):
         payload = {
             "env": self.env,
             "application": self.application,
@@ -229,6 +229,7 @@ class DirectChannel(RequestWrapper):
                 "Token": token,
                 "meseToken": mesetoken,
                 "annoToken": annotoken,
+                "flagOneOff": flagoneoff,
                 "providerincasso": providerincasso,
                 "nomeTitolare": nometitolare,
                 "codiceFiscaleTitolare": codicefiscaletitolare,
